Sorting
:::::::

.. toctree::
   :caption: Sorting
   :maxdepth: 2

   intro-SortingwithSortandSorted.rst
   Optionalreverseparameter.rst
   Optionalkeyparameter.rst
   SortingaDictionary.rst
   SecondarySortOrder.rst
   WPWhenToUseLambdaVsFunction.rst
   Glossary.rst
   Exercises.rst
   ChapterAssessment.rst
